lspreader
=========

A set of readers and scripts for the plasma code LSP's outputs.

Install
-------

Using `pip`, and installing locally,

    git pull https://github.com/noobermin/lspreader.git
    cd lspreader
    pip install . --user

